.. tricircle documentation master file, created by
   sphinx-quickstart on Wed Dec 2 17:00:36 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

=====================================
Welcome to Tricircle's documentation!
=====================================

Contents
========

.. toctree::
   :maxdepth: 3

   readme
   usage
   installation-guide
   configuration
   networking-guide
   api_v1
   contributing



Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
